@@ -16,8 +16,7 @@
 
 //! Parser for `FEEL` language.
 
-extern crate dmntk_common;
-extern crate dmntk_feel;
+pub extern crate dmntk_feel;
 
 mod lalr;
 mod lexer;
